@@ -74,7 +74,7 @@ gt_merge_stack <- function(gt_object, col1, col2, palette = c("black", "grey"),
         }
 
         glue::glue(
-          "<div style='line-height:{font_size[1]}'><span style='font-weight:{font_weight[1]};font-variant:{font_variant};color:{colors[1]};font-size:{font_size[1]}'>{x}</div>
+          "<div style='line-height:{font_size[1]}'><span style='font-weight:{font_weight[1]};font-variant:{font_variant};color:{colors[1]};font-size:{font_size[1]}'>{x}</span></div>
         <div style='line-height:{font_size[2]}'><span style ='font-weight:{font_weight[2]};color:{colors[2]};font-size:{font_size[2]}'>{data_in}</span></div>"
         )
       }
@@ -144,7 +144,7 @@ gt_merge_stack_color <- function(gt_object, top_val, color_val,
   gt_object %>%
     data_color(
       columns = {{ color_val }},
-      colors = scales::col_numeric(
+      fn = scales::col_numeric(
         palette = if (grepl(x = palette[1], pattern = "::")) {
           paletteer::paletteer_d(
             palette = palette
