@@ -3,7 +3,7 @@ test_that("gt_text_img is created and matches", {
   skip_on_cran()
   temp_nm <- tempfile(fileext = ".html")
 
-  in_title <- "https://www.r-project.org/logo/Rlogo.png"
+  in_title <- "https://upload.wikimedia.org/wikipedia/commons/thumb/f/f3/Boston_Terrier_male.jpg/330px-Boston_Terrier_male.jpg"
 
   title_car <- mtcars %>%
     head() %>%
@@ -11,7 +11,8 @@ test_that("gt_text_img is created and matches", {
     gt::tab_header(
       title = add_text_img(
         "A table about cars made with",
-        url = in_title
+        url = in_title,
+        height = px(30)
         )
       ) %>%
     gt::gtsave(temp_nm)
@@ -19,7 +20,6 @@ test_that("gt_text_img is created and matches", {
   title_html <- rvest::read_html(temp_nm)
 
   out_title <- title_html %>%
-    rvest::html_elements("th > div:nth-child(2)") %>%
     rvest::html_elements("img") %>%
     rvest::html_attr("src")
 
